==> knative-model-4.6.3-sources.jar: io/fabric8/knative/serving/v1/ServiceListFluent.java <==
package io.fabric8.knative.serving.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface ServiceListFluent<A extends ServiceListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,Service item);
    public A setToItems(int index,Service item);
    public A addToItems(Service... items);
    public A addAllToItems(Collection<Service> items);
    public A removeFromItems(Service... items);
    public A removeAllFromItems(Collection<Service> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<Service> getItems();
    public List<Service> buildItems();
    public Service buildItem(int index);
    public Service buildFirstItem();
    public Service buildLastItem();
    public Service buildMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<ServiceBuilder> predicate);
    public Boolean hasMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<ServiceBuilder> predicate);
    public A withItems(List<Service> items);
    public A withItems(Service... items);
    public Boolean hasItems();
    public ServiceListFluent.ItemsNested<A> addNewItem();
    public ServiceListFluent.ItemsNested<A> addNewItemLike(Service item);
    public ServiceListFluent.ItemsNested<A> setNewItemLike(int index,Service item);
    public ServiceListFluent.ItemsNested<A> editItem(int index);
    public ServiceListFluent.ItemsNested<A> editFirstItem();
    public ServiceListFluent.ItemsNested<A> editLastItem();
    public ServiceListFluent.ItemsNested<A> editMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<ServiceBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ServiceFluent<ServiceListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}

==> knative-model-4.9.1-sources.jar: io/fabric8/knative/serving/v1/ServiceListFluent.java <==
package io.fabric8.knative.serving.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface ServiceListFluent<A extends ServiceListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,Service item);
    public A setToItems(int index,Service item);
    public A addToItems(Service... items);
    public A addAllToItems(Collection<Service> items);
    public A removeFromItems(Service... items);
    public A removeAllFromItems(Collection<Service> items);
    public A removeMatchingFromItems(io.fabric8.kubernetes.api.builder.Predicate<ServiceBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public List<Service> getItems();
    public List<Service> buildItems();
    public Service buildItem(int index);
    public Service buildFirstItem();
    public Service buildLastItem();
    public Service buildMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<ServiceBuilder> predicate);
    public Boolean hasMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<ServiceBuilder> predicate);
    public A withItems(List<Service> items);
    public A withItems(Service... items);
    public Boolean hasItems();
    public ServiceListFluent.ItemsNested<A> addNewItem();
    public ServiceListFluent.ItemsNested<A> addNewItemLike(Service item);
    public ServiceListFluent.ItemsNested<A> setNewItemLike(int index,Service item);
    public ServiceListFluent.ItemsNested<A> editItem(int index);
    public ServiceListFluent.ItemsNested<A> editFirstItem();
    public ServiceListFluent.ItemsNested<A> editLastItem();
    public ServiceListFluent.ItemsNested<A> editMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<ServiceBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ServiceFluent<ServiceListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}
